Module kpca

Module kpca 

Kernel PCA for nonlinear dimensionality reduction Kernel PCA (Principal Component Analysis)

Kernel PCA is a nonlinear extension of PCA that uses the kernel trick to perform PCA in a high-dimensional (potentially infinite-dimensional) feature space without explicitly computing the feature map.

Algorithm

  1. Compute the kernel (Gram) matrix K
  2. Center K in feature space
  3. Eigendecompose the centered K
  4. Project data using the top eigenvectors

Features

  • Nonlinear dimensionality reduction via kernel trick
  • Pre-image estimation (approximate reconstruction to input space)
  • Automatic kernel parameter selection via grid search on reconstruction error
  • Support for all kernel types in the kernels module

Structs

KernelPCA
Kernel PCA for nonlinear dimensionality reduction