Module adwin

Module adwin 

ADWIN — ADaptive WINdowing for concept drift detection

ADWIN (Bifet & Gavalda, 2007) maintains a variable-length window of recent observations and automatically shrinks the window when a statistically significant change in the mean is detected.

Algorithm

The window is stored as a compressed histogram of exponentially growing buckets (for memory efficiency). At each insertion, ADWIN tests whether any split of the current window into two contiguous sub-windows W0 and W1 yields a sufficiently large difference in means:

|mean(W0) - mean(W1)| >= epsilon_cut

where epsilon_cut is derived from Hoeffding’s bound parameterised by delta (confidence).

When a change is detected the older portion is dropped and a flag is set.

References

  • Bifet, A., & Gavalda, R. (2007). “Learning from Time-Changing Data with Adaptive Windowing”. SDM 2007.

Structs

Adwin
ADWIN drift detector for streaming data.