Module normalize

Module normalize 

Basic normalization methods for data Data normalization and standardization utilities

This module provides functions for normalizing and standardizing data, which is often a preprocessing step for machine learning algorithms.

Structs

Normalizer
Represents a fitted normalization model that can transform new data

Enums

NormalizationMethod
Method of normalization to apply

Constants

EPSILON
Small value to use for comparison with zero and numerical stability

Functions

normalize_array
Normalizes a 2D array along a specified axis
normalize_vector
Normalizes a 1D array