scree_plot_data

Function scree_plot_data 

pub fn scree_plot_data<S>(
    data: &ArrayBase<S, Ix2>,
    use_correlation: bool,
) -> Result<ScreePlotData>
where S: Data, S::Elem: Float + NumCast,
Convenience function to compute scree plot data for factor selection

Returns eigenvalues and variance proportions that can be used to determine the appropriate number of factors via the scree plot method (look for the “elbow”) or Kaiser criterion (eigenvalues > threshold).

Arguments

  • data - Input data, shape (n_samples, n_features)
  • use_correlation - If true, use correlation matrix; if false, use covariance

Returns

  • Result<ScreePlotData> - Eigenvalues and variance information