pub struct FactorAnalysis { /* private fields */ }Expand description
Factor Analysis for dimensionality reduction
Factor Analysis assumes observed data is generated from a linear model with latent factors plus Gaussian noise with feature-specific variances.
Example
use scirs2_transform::reduction::factor_analysis::FactorAnalysis;
use scirs2_core::ndarray::Array2;
let data = Array2::<f64>::zeros((100, 10));
let mut fa = FactorAnalysis::new(3);
let result = fa.fit_transform(&data).expect("fit_transform failed");
println!("Loadings shape: {:?}", result.loadings.shape());
println!("Scores shape: {:?}", result.scores.shape());Implementations
Sourceimpl FactorAnalysis
impl FactorAnalysis
Sourcepub fn with_rotation(self, rotation: RotationMethod) -> Self
pub fn with_rotation(self, rotation: RotationMethod) -> Self
Set the rotation method
Sourcepub fn with_max_iter(self, max_iter: usize) -> Self
pub fn with_max_iter(self, max_iter: usize) -> Self
Set the maximum number of EM iterations
Sourcepub fn with_promax_power(self, power: usize) -> Self
pub fn with_promax_power(self, power: usize) -> Self
Set the promax power parameter
Sourcepub fn with_center(self, center: bool) -> Self
pub fn with_center(self, center: bool) -> Self
Set whether to center the data
Sourcepub fn fit_transform<S>(
&mut self,
x: &ArrayBase<S, Ix2>,
) -> Result<FactorAnalysisResult>
pub fn fit_transform<S>( &mut self, x: &ArrayBase<S, Ix2>, ) -> Result<FactorAnalysisResult>
Sourcepub fn uniquenesses(&self) -> Option<&Array1<f64>>
pub fn uniquenesses(&self) -> Option<&Array1<f64>>
Returns the uniquenesses
Sourcepub fn scree_plot_data<S>(
x: &ArrayBase<S, Ix2>,
use_correlation: bool,
) -> Result<ScreePlotData>
pub fn scree_plot_data<S>( x: &ArrayBase<S, Ix2>, use_correlation: bool, ) -> Result<ScreePlotData>
Compute scree plot data from a data matrix
Computes eigenvalues of the covariance (or correlation) matrix, which can be used for scree plots to determine the number of factors.
Arguments
x- Input data, shape (n_samples, n_features)use_correlation- If true, use the correlation matrix instead of covariance
Returns
Result<ScreePlotData>- Eigenvalues and variance proportions