pub struct Barcode {
pub intervals: Vec<BarcodeInterval>,
pub max_dimension: usize,
}Expand description
Persistence barcode: a multi-set of intervals representing topological features.
Each interval [birth, death) represents a topological feature that appears
at filtration value birth and disappears at filtration value death.
Fields
intervals: Vec<BarcodeInterval>All barcode intervals
max_dimension: usizeMaximum dimension
Implementations
Sourceimpl Barcode
impl Barcode
Sourcepub fn from_diagram(diagram: &PersistenceDiagram) -> Self
pub fn from_diagram(diagram: &PersistenceDiagram) -> Self
Create a barcode from a persistence diagram
Sourcepub fn intervals_in_dimension(&self, dim: usize) -> Vec<&BarcodeInterval>
pub fn intervals_in_dimension(&self, dim: usize) -> Vec<&BarcodeInterval>
Get intervals in a specific dimension, sorted by birth