pub struct PersistenceDiagram {
pub points: Vec<PersistencePoint>,
pub max_dimension: usize,
}Expand description
Persistence diagram: a collection of (birth, death) pairs per dimension.
A persistence diagram captures the topological features of a dataset across all scales, organized by homological dimension.
Fields
points: Vec<PersistencePoint>All persistence points across all dimensions
max_dimension: usizeMaximum homological dimension computed
Implementations
Sourceimpl PersistenceDiagram
impl PersistenceDiagram
Sourcepub fn add_point(&mut self, birth: f64, death: f64, dimension: usize)
pub fn add_point(&mut self, birth: f64, death: f64, dimension: usize)
Add a persistence point to the diagram
Sourcepub fn points_in_dimension(&self, dim: usize) -> Vec<&PersistencePoint>
pub fn points_in_dimension(&self, dim: usize) -> Vec<&PersistencePoint>
Get all points in a specific homological dimension
Sourcepub fn finite_points(&self) -> Vec<&PersistencePoint>
pub fn finite_points(&self) -> Vec<&PersistencePoint>
Get all finite persistence points (non-essential features)
Sourcepub fn essential_points(&self) -> Vec<&PersistencePoint>
pub fn essential_points(&self) -> Vec<&PersistencePoint>
Get all essential points (infinite persistence)
Sourcepub fn total_persistence(&self, p: f64) -> f64
pub fn total_persistence(&self, p: f64) -> f64
Compute the total persistence (sum of all finite persistence values)
Sourcepub fn filter_by_persistence(&self, min_persistence: f64) -> PersistenceDiagram
pub fn filter_by_persistence(&self, min_persistence: f64) -> PersistenceDiagram
Filter points by minimum persistence threshold
Sourcepub fn to_barcode(&self) -> Barcode
pub fn to_barcode(&self) -> Barcode
Convert to barcode representation
Sourcepub fn betti_numbers_at(&self, filtration_value: f64) -> Vec<usize>
pub fn betti_numbers_at(&self, filtration_value: f64) -> Vec<usize>
Get the Betti numbers (count of features) at a given filtration value